/*
 * controller.hpp
 *
 * This file is part of Knights.
 *
 * Copyright (C) Stephen Thompson, 2006 - 2009.
 * Copyright (C) Kalle Marjola, 1994.
 *
 * Knights is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Knights is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Knights.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

/*
 * "Controllers" act as an interface between the LocalDungeonView (in
 * particular, LocalDungeonView::getStick) and the input device
 * itself.
 *
 */

#ifndef CONTROLLER_HPP
#define CONTROLLER_HPP

#include "map_support.hpp"

#include "gfx/key_code.hpp"

#include <vector>

class Controller {
public:
    virtual ~Controller() { }

    // Controllers have up/down/left/right, fire and suicide.
    virtual void get(MapDirection &dir, bool &centred, bool &fire_held,
                     bool &suicide_held) const = 0;

    // "reserved" keys cannot be used in the gui chat box.
    virtual std::vector<Coercri::KeyCode> getReservedKeys() const {
        return std::vector<Coercri::KeyCode>();
    }
};

#endif
