/*
 * options.cpp
 *
 * This file is part of Knights.
 *
 * Copyright (C) Stephen Thompson, 2006 - 2009.
 * Copyright (C) Kalle Marjola, 1994.
 *
 * Knights is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Knights is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Knights.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "misc.hpp"

#include "config_map.hpp"
#include "options.hpp"

#include <cctype>
#include <cstring>

Options::Options()
{
    ctrls[0][0] = Coercri::KC_W;
    ctrls[0][1] = Coercri::KC_S;
    ctrls[0][2] = Coercri::KC_A;
    ctrls[0][3] = Coercri::KC_D;
    ctrls[0][4] = Coercri::KC_Q;
    ctrls[0][5] = Coercri::KC_F1;

    ctrls[1][0] = Coercri::KC_UP;
    ctrls[1][1] = Coercri::KC_DOWN;
    ctrls[1][2] = Coercri::KC_LEFT;
    ctrls[1][3] = Coercri::KC_RIGHT;
    ctrls[1][4] = Coercri::KC_RIGHT_CONTROL;
    ctrls[1][5] = Coercri::KC_F12;

    for (int i = 0; i < 6; ++i) ctrls[2][i] = ctrls[1][i];
    
    use_scale2x = true;
    fullscreen = true;

    allow_non_integer_scaling = false;
    window_width = 950;
    window_height = 710;
}

Options LoadOptions(std::istream &str)
{
    Options o;

    char buf[8] = {0};
    str.getline(buf, 6);

    const bool version1 = (std::strcmp(buf, "KOPT1") == 0);
    const bool version2 = (std::strcmp(buf, "KOPT2") == 0);
    const bool version3 = (std::strcmp(buf, "KOPT3") == 0);

    if (!version1 && !version2 && !version3) return Options();

    const bool version2plus = version2 || version3;
    const bool version3plus = version3;

    bool load_ok = false;

    // All Versions
    for (int i = 0; i < 3; ++i) {
        for (int j = 0; j < 6; ++j) {
            if (i<2 || version3plus) {
                // Read from file.
                int x;
                str >> x;
                o.ctrls[i][j] = Coercri::KeyCode(x);
            } else {
                // Versions prior to 3 only have 2 sets of controls in the file.
                // Copy the "network games" controls from the P2 controls.
                o.ctrls[i][j] = o.ctrls[1][j];
            }
        }
    }
    str >> o.use_scale2x;
    str >> o.fullscreen;

    // Version 2+
    if (version2plus) {
        str >> o.allow_non_integer_scaling;
        str >> o.window_width >> o.window_height;
    }

    // Version 3+
    if (version3plus) {
        // Ignore any errors on loading the player name
        // (in particular we want to ignore any EOF error if the player name is blank).
        if (str) load_ok = true;

        // eat white space
        char c;
        while (str.get(c)) {
            if (!std::isspace(c)) {
                str.putback(c);
                break;
            }
        }
        
        std::getline(str, o.player_name);
    }

    if (!str && !load_ok) return Options();  // In case of load failure, return default options
    else return o;
}

void SaveOptions(const Options &o, std::ostream &str)
{
    str << "KOPT3\n";
    for (int i = 0; i < 3; ++i) {
        for (int j = 0; j < 6; ++j) {
            str << o.ctrls[i][j] << " ";
        }
        str << "\n";
    }
    str << o.use_scale2x << "\n";
    str << o.fullscreen << "\n";
    str << o.allow_non_integer_scaling << "\n";
    str << o.window_width << " " << o.window_height << "\n";
    str << o.player_name << "\n";
}
